//
//*****************************************************************************
// Build 0135
//
// Project:  GDAL Lazarus Bindings
// Purpose:  Types and Constants for GDAL
// Author:   Frank Warmerdam, warmerdam@pobox.com
// Lazarus Wrapper : Prajuab Riabroy
//*****************************************************************************
// Copyright (c) 2005, Frank Warmerdam <warmerdam@pobox.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//*****************************************************************************

unit gdal;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils;

const
  //External_lib = 'gdal';
  External_lib = 'gdal16.dll';


type
  TGInt32   = longint;
  TGUInt32  = longword;
  TGInt16   = shortInt;
  TGUInt16  = word;
  TGByte    = byte;
  TGBool    = boolean;
  TGFloat32 = single;
  TGFloat64 = double;

  PGInt32   = ^TGInt32;
  PGUInt32  = ^TGUInt32;
  PGInt16   = ^TGInt16;
  PGUInt16  = ^TGUInt16;
  PGByte    = ^TGByte;
  PGBool    = ^TGBool;
  PGFloat32 = ^TGFloat32;
  PGFloat64 = ^TGFloat64;

  PPINTEGER = ^PINTEGER;

  TDynArrayDouble = array of double;
  TDynArrayInt16  = array of shortint;
  TDoubleArray6 = array[0..5] of double;
  TDoubleArray2 = array[0..1] of double;
  TDoubleArray7 = array[0..6] of double;

  //* -------------------------------------------------------------------- */
  //*      Significant constants.                                          */
  //* -------------------------------------------------------------------- */
  TCPLErr   =  (CE_None = 0, CE_Debug = 1, CE_Warning = 2, CE_Failure = 3,
                       CE_Fatal = 4);
  //*! Pixel data types */
  TGDALDataType = (GDT_Unknown = 0, GDT_Byte = 1, GDT_UInt16 = 2, GDT_Int16 = 3,
                   GDT_UInt32 = 4, GDT_Int32 = 5, GDT_Float32 = 6, GDT_Float64 = 7,
                   GDT_CInt16 = 8, GDT_CInt32 = 9, GDT_CFloat32 = 10, GDT_CFloat64 = 11,
                   GDT_TypeCount = 12);
  //*! Flag indicating read/write, or read-only access to data. */
  TGDALAccess = (GA_ReadOnly = 0, GA_Update = 1);
  //*! Read/Write flag for RasterIO() method */
  TGDALRWFlag = (GF_Read = 0, GF_Write = 1);
  //*! Types of color interpretation for raster bands. */
  TGDALColorInterp = (GCI_Undefined = 0, GCI_GrayIndex = 1, GCI_PaletteIndex = 2, GCI_RedBand = 3,
                      GCI_GreenBand = 4, GCI_BlueBand = 5, GCI_AlphaBand = 6, GCI_HueBand = 7,
                      GCI_SaturationBand = 8, GCI_LightnessBand = 9, GCI_CyanBand = 10, GCI_MagentaBand = 11,
                      GCI_YellowBand = 12, GCI_BlackBand = 13, GCI_YCbCr_YBand = 14, GCI_YCbCr_CbBand = 15,
                      GCI_YCbCr_CrBand = 16, GCI_Max = 16);
  //*! Types of color interpretations for a GDALColorTable. */
  TGDALPaletteInterp = (GPI_Gray = 0, GPI_RGB = 1, GPI_CMYK = 2, GPI_HLS = 3);
  TGDALRATFieldType = (GFT_Integer, GFT_Real, GFT_String);
  TGDALRATFieldUsage = (GFU_Generic = 0, GFU_PixelCount = 1, GFU_Name = 2, GFU_Min = 3,
                        GFU_Max = 4, GFU_MinMax = 5, GFU_Red = 6, GFU_Green = 7,
                        GFU_Blue = 8, GFU_Alpha = 9, GFU_RedMin = 10, GFU_GreenMin = 11,
                        GFU_BlueMin = 12, GFU_AlphaMin = 13, GFU_RedMax = 14, GFU_GreenMax = 15,
                        GFU_BlueMax = 16, GFU_AlphaMax = 17, GFU_MaxCount);

  //* -------------------------------------------------------------------- */
  //*      Callback "progress" function.                                   */
  //* -------------------------------------------------------------------- */
  TGDALProgressFunc = function(dfComplete : double; const pszMessage : PCHAR;
                              pProgressArg : POINTER) : longint;
  TGDALDerivedPixelFunc = function(papoSources : PPOINTER; nSources : longint;
                                  pData : POINTER; nBufXSize, nBufYSize : longint;
                                  eSrcType : TGDALDataType;
                                  eBufType : TGDALDataType;
                                  nPixelSpace, nLineSpace : longint): TCPLErr;

  //* -------------------------------------------------------------------- */
  //*      Define handle types related to various internal classes.        */
  //* -------------------------------------------------------------------- */
  TGDALMajorObjectH = POINTER;
  TGDALDatasetH = POINTER;
  TGDALRasterBandH = POINTER;
  TGDALDriverH = POINTER;
  TGDALColorTableH = POINTER;
  TGDALRasterAttributeTableH = POINTER;

  PGDALRasterBandH = ^TGDALRasterBandH;
  PGDALDatasetH = ^TGDALDatasetH;
  PPGDALDatasetH = ^PGDALDatasetH;

const
//* ==================================================================== */
//*      Registration/driver related.                                    */
//* ==================================================================== */
  DMD_SHORTNAME : PCHAR = 'DMD_SHORTNAME';
  DMD_LONGNAME : PCHAR = 'DMD_LONGNAME';
  DMD_HELPTOPIC : PCHAR = 'DMD_HELPTOPIC';
  DMD_MIMETYPE : PCHAR = 'DMD_MIMETYPE';
  DMD_EXTENSION : PCHAR = 'DMD_EXTENSION';
  DMD_CREATIONOPTIONLIST : PCHAR = 'DMD_CREATIONOPTIONLIST';
  DMD_CREATIONDATATYPES : PCHAR = 'DMD_CREATIONDATATYPES';

  DCAP_CREATE : PCHAR = 'DCAP_CREATE';
  DCAP_CREATECOPY : PCHAR = 'DCAP_CREATECOPY';

  GDALMD_AREA_OR_POINT = 'AREA_OR_POINT';
  GDALMD_AOP_AREA = 'Area';
  GDALMD_AOP_POINT = 'Point';
  CPLE_WrongFormat  = 200;
  GDAL_DMD_LONGNAME = 'DMD_LONGNAME';
  GDAL_DMD_HELPTOPIC = 'DMD_HELPTOPIC';
  GDAL_DMD_MIMETYPE = 'DMD_MIMETYPE';
  GDAL_DMD_EXTENSION = 'DMD_EXTENSION';
  GDAL_DMD_CREATIONOPTIONLIST = 'DMD_CREATIONOPTIONLIST';
  GDAL_DMD_CREATIONDATATYPES = 'DMD_CREATIONDATATYPES';
  GDAL_DCAP_CREATE = 'DCAP_CREATE';
  GDAL_DCAP_CREATECOPY = 'DCAP_CREATECOPY';
  GDAL_DCAP_VIRTUALIO = 'DCAP_VIRTUALIO';
  //SRCVAL(papoSource, eSrcType, ii)
  //SRCVAL - Macro which may be used by pixel functions to obtain a pixel from a source buffer.
  GMF_ALL_VALID  = $01;
  GMF_PER_DATASET =  $02;
  GMF_ALPHA  = $04;
  GMF_NODATA  = $08;

type
  TGDAL_GCP = record
    pszId : PCHAR;//Unique identifier, often numeric.
    pszInfo : PCHAR;//Informational message or "".
    dfGCPPixel : double;//Pixel (x) location of GCP on raster.
    dfGCPLine : double;//Line (y) location of GCP on raster.
    dfGCPX : double;//X position of GCP in georeferenced space.
    dfGCPY : double;//Y position of GCP in georeferenced space.
    dfGCPZ : double;//Elevation of GCP, or zero if not known.
  end;
  PGDAL_GCP = ^TGDAL_GCP;

  TGDALColorEntry = record
    c1 : shortint;
    c2 : shortint;
    c3 : shortint;
    c4 : shortint;
  end;
  PGDALColorEntry = ^TGDALColorEntry;

  TGDALRPCInfo = record
    dfLINE_OFF : double;
    dfSAMP_OFF : double;
    dfLAT_OFF  : double;
    dfLONG_OFF : double;
    dfHEIGHT_OFF : double;
    dfLINE_SCALE : double;
    dfSAMP_SCALE : double;
    dfLAT_SCALE  : double;
    dfLONG_SCALE : double;
    dfHEIGHT_SCALE : double;
    adfLINE_NUM_COEFF : array[0..20] of double;
    adfLINE_DEN_COEFF : array[0..20] of double;
    adfSAMP_NUM_COEFF : array[0..20] of double;
    adfSAMP_DEN_COEFF : array[0..20] of double;
    dfMIN_LONG : double;
    dfMIN_LAT  : double;
    dfMAX_LONG : double;
    dfMAX_LAT  : double;
  end;
  PGDALRPCInfo = ^TGDALRPCInfo;

implementation

end.

