{'*****************************************************************************
' Build 0135
'
' Project:  GDAL Lazarus Bindings
' Purpose:  OGR Lazarus internal support functions.
' Author:   Frank Warmerdam, warmerdam@pobox.com
' Lazarus Wrapper : Prajuab Riabroy
'*****************************************************************************
' Copyright (c) 2005, Frank Warmerdam <warmerdam@pobox.com>
'
' Permission is hereby granted, free of charge, to any person obtaining a
' copy of this software and associated documentation files (the "Software"),
' to deal in the Software without restriction, including without limitation
' the rights to use, copy, modify, merge, publish, distribute, sublicense,
' and/or sell copies of the Software, and to permit persons to whom the
' Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included
' in all copies or substantial portions of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
' OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
' FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
' LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
' FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
' DEALINGS IN THE SOFTWARE.
'*****************************************************************************
}

unit ogrcore;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, gdal, ogr;

  procedure OGRFree(p : POINTER); cdecl; external External_Lib name 'OGRFree';

  function OSRNewSpatialReference(const WKT : PCHAR
                                 ) : TOGRSpatialReferenceH;
                                 stdcall; external External_Lib name '_OSRNewSpatialReference@4';
  function OSRCloneGeogCS(const Handle : TOGRSpatialReferenceH
                         ) : TOGRSpatialReferenceH;
                         stdcall; external External_Lib name '_OSRCloneGeogCS@4';

  function  OSRClone(const Handle : TOGRSpatialReferenceH ) : TOGRSpatialReferenceH ;
                    stdcall; external External_Lib name '_OSRClone@4';
  procedure OSRDestroySpatialReference (const Handle : TOGRSpatialReferenceH); stdcall; external External_Lib name '_OSRDestroySpatialReference@4';

  function  OSRReference(hSRS : TOGRSpatialReferenceH) : longint; cdecl; external External_Lib name 'OSRReference';
  function  OSRDereference(hSRS : TOGRSpatialReferenceH) : longint; cdecl; external External_Lib name 'OSRDereference';
  procedure OSRRelease(hSRS : TOGRSpatialReferenceH ); cdecl; external External_Lib name 'OSRRelease';
  function  OSRValidate(hSRS : TOGRSpatialReferenceH ) : TOGRErr; cdecl; external External_Lib name 'OSRValidate';
  function  OSRFixupOrdering(hSRS : TOGRSpatialReferenceH) : TOGRErr; cdecl; external External_Lib name 'OSRFixupOrdering';
  function  OSRFixup(hSRS : TOGRSpatialReferenceH ) : TOGRErr; cdecl; external External_Lib name 'OSRFixup';
  function  OSRStripCTParms(hSRS : TOGRSpatialReferenceH) : TOGRErr; cdecl; external External_Lib name 'OSRStripCTParms';

  function  OSRImportFromEPSG(hSRS : TOGRSpatialReferenceH; EPSGCode : longint
                                 ) : TOGRErr; stdcall; external External_Lib name '_OSRImportFromEPSG@8';
  function  OSRImportFromWkt(hSRS : TOGRSpatialReferenceH;
                             ppszInput : PPCHAR
                             ) : TOGRErr; cdecl; external External_Lib name 'OSRImportFromWkt';
  function  OSRImportFromProj4(hSRS : TOGRSpatialReferenceH;
                               pszProj4 : PCHAR) : TOGRErr; cdecl; external External_Lib name 'OSRImportFromProj4';
  function  OSRImportFromESRI(hSRS : TOGRSpatialReferenceH;
                               papszPrj : PPCHAR) : TOGRErr; cdecl; external External_Lib name 'OSRImportFromESRI';
  function  OSRImportFromPCI(hSRS : TOGRSpatialReferenceH; pszProj : PCHAR;
		             pszUnits : PCHAR; padfPrjParams : PDOUBLE
                             ) : TOGRErr; cdecl; external External_Lib name 'OSRImportFromPCI';
  function  OSRImportFromUSGS(hSRS : TOGRSpatialReferenceH; iProjsys : longint;
                              iZone : longint; padfPrjParams : PDOUBLE;
                              iDatum : longint
                              ) : TOGRErr; cdecl; external External_Lib name 'OSRImportFromUSGS';
  function  OSRImportFromXML(hSRS : TOGRSpatialReferenceH;
                              pszXML : PCHAR) : TOGRErr; cdecl; external External_Lib name 'OSRImportFromXML';
  function  OSRImportFromMICoordSys(hSRS : TOGRSpatialReferenceH;
                                    pszCoordSys : PCHAR
                                   ) : TOGRErr; cdecl; external External_Lib name 'OSRImportFromMICoordSys';
  function  OSRImportFromUrl(hSRS : TOGRSpatialReferenceH;
                             pszUrl : PCHAR
                            ) : TOGRErr; cdecl; external External_Lib name 'OSRImportFromUrl';

  function  OSRExportToWkt(hSRS : TOGRSpatialReferenceH;
                           ppszReturn : PPCHAR) : TOGRErr; stdcall; external External_Lib name '_OSRExportToWkt@8';
  function  OSRExportToPrettyWkt(hSRS : TOGRSpatialReferenceH;
                                 ppszReturn : PPCHAR;
                                 bSimplify: longint) : TOGRErr; stdcall; external External_Lib name '_OSRExportToPrettyWkt@12';

  function  OSRExportToProj4(hSRS : TOGRSpatialReferenceH;
                             ppszReturn : PPCHAR) : TOGRErr; stdcall; external External_Lib name '_OSRExportToProj4@8';
  function  OSRExportToPCI(hSRS : TOGRSpatialReferenceH; ppszProj : PPCHAR;
                           ppszUnits : PPCHAR;
                           ppadfPrjParams : PPDOUBLE
                           ) : TOGRErr; cdecl; external External_Lib name 'OSRExportToPCI';
  function  OSRExportToUSGS(hSRS : TOGRSpatialReferenceH; piProjSys : PINTEGER;
                            piZone : PLONGINT;
                            ppadfPrjParams : PPDOUBLE;
                            piDatum : PLONGINT
                            ) : TOGRErr; cdecl; external External_Lib name 'OSRExportToUSGS';
  function  OSRExportToXML(hSRS : TOGRSpatialReferenceH; ppszRawXML : PPCHAR;
                           pszDialect : PCHAR
                           ) : TOGRErr; cdecl; external External_Lib name 'OSRExportToXML';
  function  OSRExportToMICoordSys(hSRS : TOGRSpatialReferenceH;
                                  ppszReturn : PPCHAR) : TOGRErr; cdecl; external External_Lib name 'OSRExportToMICoordSys';

  function  OSRMorphToESRI(hSRS : TOGRSpatialReferenceH) : TOGRErr; cdecl; external External_Lib name 'OSRMorphToESRI';
  function  OSRMorphFromESRI(hSRS : TOGRSpatialReferenceH) : TOGRErr; cdecl; external External_Lib name 'OSRMorphFromESRI';

  function  OSRSetAttrValue(hSRS : TOGRSpatialReferenceH;
                            pszNodePath : PCHAR;
                            pszNewNodeValue : PCHAR) : TOGRErr; stdcall; external External_Lib name '_OSRSetAttrValue@12';
  function  OSRGetAttrValue(hSRS : TOGRSpatialReferenceH;
                            pszName : PCHAR;
                            iChild  : longint(* = 0 *)) : PCHAR; stdcall; external External_Lib name '_OSRGetAttrValue@12';

  function  OSRSetAngularUnits(hSRS : TOGRSpatialReferenceH; pszUnits : PCHAR;
                               dfInRadians : double) : TOGRErr; cdecl; external External_Lib name 'OSRSetAngularUnits';
  function  OSRGetAngularUnits(hSRS : TOGRSpatialReferenceH;
                               ppszName : PPCHAR) : double; cdecl; external External_Lib name 'OSRGetAngularUnits';
  function  OSRSetLinearUnits(hSRS : TOGRSpatialReferenceH; pszUnits : PCHAR;
                              dfInMeters : double) : TOGRErr; cdecl; external External_Lib name 'OSRSetLinearUnits';
  function  OSRSetLinearUnitsAndUpdateParameters(hSRS : TOGRSpatialReferenceH;
                                                 pszUnits : PCHAR;
                                                 dfInMeters : double
                                                 ) : TOGRErr; cdecl; external External_Lib name 'OSRSetLinearUnitsAndUpdateParameters';
  function  OSRGetLinearUnits(hSRS : TOGRSpatialReferenceH;
                              ppszName : PPCHAR) : double; cdecl; external External_Lib name 'OSRGetLinearUnits';
  function  OSRGetPrimeMeridian(hSRS : TOGRSpatialReferenceH;
                                ppszName : PPCHAR) : double; cdecl; external External_Lib name 'OSRGetPrimeMeridian';
  function  OSRIsGeographic(hSRS : TOGRSpatialReferenceH) : longint; cdecl; external External_Lib name 'OSRIsGeographic';
  function  OSRIsLocal(hSRS : TOGRSpatialReferenceH) : longint; cdecl; external External_Lib name 'OSRIsLocal';
  function  OSRIsProjected(hSRS : TOGRSpatialReferenceH) : longint; cdecl; external External_Lib name 'OSRIsProjected';
  function  OSRIsSameGeogCS(hSRS1 : TOGRSpatialReferenceH;
                            hSRS2 : TOGRSpatialReferenceH) : longint; cdecl; external External_Lib name 'OSRIsSameGeogCS';
  function  OSRIsSame(hSRS1 : TOGRSpatialReferenceH;
                      hSRS2 : TOGRSpatialReferenceH) : longint; cdecl; external External_Lib name 'OSRIsSame';
  function  OSRSetLocalCS(hSRS : TOGRSpatialReferenceH;
                          pszName : PCHAR) : TOGRErr; cdecl; external External_Lib name 'OSRSetLocalCS';
  function  OSRSetProjCS(hSRS : TOGRSpatialReferenceH;
                         pszName : PCHAR) : TOGRErr; cdecl; external External_Lib name 'OSRSetProjCS';
  function  OSRSetWellKnownGeogCS(hSRS : TOGRSpatialReferenceH;
                                  pszName : PCHAR) : TOGRErr; cdecl; external External_Lib name 'OSRSetWellKnownGeogCS';

  function  OSRSetFromUserInput(hSRS : TOGRSpatialReferenceH;
                                pszDef : PCHAR): TOGRErr; stdcall; external External_Lib name '_OSRSetFromUserInput@8';

  function  OSRCopyGeogCSFrom(hSRS : TOGRSpatialReferenceH;
                              hSrcSRS : TOGRSpatialReferenceH
                              ) : TOGRErr; cdecl; external External_Lib name 'OSRCopyGeogCSFrom';
  function  OSRSetTOWGS84(hSRS :  TOGRSpatialReferenceH;
                          dfDX, dfDY,
                          dfDZ, dfEX,
                          dfEY, dfEZ,
                          dfPPM : double
                          ) : TOGRErr; cdecl; external External_Lib name 'OSRSetTOWGS84';
  function  OSRGetTOWGS84(hSRS : TOGRSpatialReferenceH; padfCoeff : PDOUBLE;
                          nCoeffCount : longint) : TOGRErr; cdecl; external External_Lib name 'OSRGetTOWGS84';
  function  OSRSetGeogCS(hSRS : TOGRSpatialReferenceH;
                         pszGeogName, pszDatumName, pszEllipsoidName : PCHAR;
                         dfSemiMajor, dfInvFlattening : double;
                         pszPMName : PCHAR; (* = NULL *)
                         dfPMOffset : double; (* = 0.0 *)
                         pszUnits : PCHAR;(* = NULL *)
                         dfConvertToRadians : double(* = 0.0 *)
                         ) : TOGRErr; cdecl; external External_Lib name 'OSRSetGeogCS';

  function  OSRGetSemiMajor(hSRS : TOGRSpatialReferenceH;
                            pnErr : POGRErr) : double; cdecl; external External_Lib name 'OSRGetSemiMajor';
  function  OSRGetSemiMinor(hSRS : TOGRSpatialReferenceH;
                            pnErr : POGRErr) : double; cdecl; external External_Lib name 'OSRGetSemiMinor';
  function  OSRGetInvFlattening(hSRS : TOGRSpatialReferenceH;
                                pnErr : POGRErr) : double; cdecl; external External_Lib name 'OSRGetInvFlattening';
  function  OSRSetAuthority(hSRS :  TOGRSpatialReferenceH;
                            pszTargetKey : PCHAR;
                            pszAuthority : PCHAR;
                            nCode : longint) : TOGRErr; cdecl; external External_Lib name 'OSRSetAuthority';
  function  OSRGetAuthorityCode(hSRS : TOGRSpatialReferenceH;
                                pszTargetKey : PCHAR) : PCHAR; cdecl; external External_Lib name 'OSRGetAuthorityCode';
  function  OSRGetAuthorityName(hSRS : TOGRSpatialReferenceH;
                                pszTargetKey : PCHAR) : PCHAR; cdecl; external External_Lib name 'OSRGetAuthorityName';
  function  OSRSetProjection(hSRS : TOGRSpatialReferenceH;
                             pszProjection : PCHAR) : TOGRErr; cdecl; external External_Lib name 'OSRSetProjection';
  function  OSRSetProjParm(hSRS : TOGRSpatialReferenceH;
                           pszParmName : PCHAR;
                           dfValue : double
                           ) : TOGRErr; cdecl; external External_Lib name 'OSRSetProjParm';
  function  OSRGetProjParm(hSRS :  TOGRSpatialReferenceH;
                           pszParmName : PCHAR;
                           dfDefault : double;
                           pnErr : POGRErr
                           ) : double; cdecl; external External_Lib name 'OSRGetProjParm';
  function   OSRSetNormProjParm(hSRS : TOGRSpatialReferenceH;
                                pszParmName : PCHAR;
                                dfValue : double
                                ) : TOGRErr; cdecl; external External_Lib name 'OSRSetNormProjParm';
  function   OSRGetNormProjParm(hSRS :  TOGRSpatialReferenceH;
                                pszParmName : PCHAR;
                                dfDefault : double;
                                pnErr : POGRErr
                                ) : double; cdecl; external External_Lib name 'OSRGetNormProjParm';
  function   OSRSetUTM(hSRS :  TOGRSpatialReferenceH;
                       nZone : longint;
                       bNorth : longint
                       ) : TOGRErr; cdecl; external External_Lib name 'OSRSetUTM';
  function   OSRGetUTMZone(hSRS :  TOGRSpatialReferenceH;
                           pbNorth : PINTEGER
                           ) : longint; cdecl; external External_Lib name 'OSRGetUTMZone';
  //** Albers Conic Equal Area */
  function   OSRSetACEA(hSRS :  TOGRSpatialReferenceH;
                        dfStdP1, dfStdP2,
                        dfCenterLat, dfCenterLong,
                        dfFalseEasting, dfFalseNorthing : double
                        ) : TOGRErr; cdecl; external External_Lib name 'OSRSetACEA';

  //** Azimuthal Equidistant */
  function    OSRSetAE(hSRS :  TOGRSpatialReferenceH;
                       dfCenterLat, dfCenterLong,
                       dfFalseEasting, dfFalseNorthing : double
                       ) : TOGRErr; cdecl; external External_Lib name 'OSRSetACEA';

  //** Bonne */
  function   OSRSetBonne(hSRS : TOGRSpatialReferenceH;
                         dfStandardParallel, dfCentralMeridian,
                         dfFalseEasting, dfFalseNorthing : double
                         ) : TOGRErr; cdecl; external External_Lib name 'OSRSetBonne';

  //** Cylindrical Equal Area */
  function   OSRSetCEA(hSRS :  TOGRSpatialReferenceH;
                       dfStdP1, dfCentralMeridian,
                       dfFalseEasting, dfFalseNorthing : double
                       ) : TOGRErr; cdecl; external External_Lib name 'OSRSetCEA';

  //** Cassini-Soldner */
  function   OSRSetCS(hSRS :  TOGRSpatialReferenceH;
                      dfCenterLat, dfCenterLong,
                      dfFalseEasting, dfFalseNorthing : double
                      ) : TOGRErr; cdecl; external External_Lib name 'OSRSetCS';

  //** Equidistant Conic */
  function   OSRSetEC(hSRS :  TOGRSpatialReferenceH;
                      dfStdP1, dfStdP2,
                      dfCenterLat, dCenterLong,
                      dfFalseEasting, dfFalseNorthing : double
                      ) : TOGRErr; cdecl; external External_Lib name 'OSRSetEC';

  ///** Eckert I-VI */
  function   OSRSetEckert(hSRS :  TOGRSpatialReferenceH;
                          nVariation : longint;
                          dfCentralMeridian,
                          dfFalseEasting,
                          dfFalseNorthing : double
                          ) : TOGRErr; cdecl; external External_Lib name 'OSRSetEckert';

  //** Eckert IV */
  function   OSRSetEckertIV(hSRS :  TOGRSpatialReferenceH;
                            dfCentralMeridian,
                            dfFalseEasting,
                            dfFalseNorthing : double
                            ) : TOGRErr; cdecl; external External_Lib name 'OSRSetEckertIV';

  //** Eckert VI */
  function   OSRSetEckertVI(hSRS :  TOGRSpatialReferenceH;
                            dfCentralMeridian,
                            dfFalseEasting,
                            dfFalseNorthing : double
                            ) : TOGRErr; cdecl; external External_Lib name 'OSRSetEckertVI';

  //** Equirectangular */
  function   OSRSetEquirectangular(hSRS : TOGRSpatialReferenceH;
                                   dfCenterLat, dfCenterLong,
                                   dfFalseEasting, dfFalseNorthing : double
                                   ) : TOGRErr; cdecl; external External_Lib name 'OSRSetEquirectangular';
  //** Equirectangular generalized form */
  function   OSRSetEquirectangular2(hSRS : TOGRSpatialReferenceH;
                                    dfCenterLat, dfCenterLong,
                                    dfPseudoStdParallel1,
                                    dfFalseEasting,
                                    dfFalseNorthing : double
                                    ) : TOGRErr; cdecl; external External_Lib name 'OSRSetEquirectangular2';

  //** Gall Stereograpic */
  function   OSRSetGS(hSRS :  TOGRSpatialReferenceH;
                      dfCentralMeridian,
                      dfFalseEasting,
                      dfFalseNorthing : double
                      ) : TOGRErr; cdecl; external External_Lib name 'OSRSetGS';

  //** Goode Homolosine */
  function   OSRSetGH(hSRS :  TOGRSpatialReferenceH;
                      dfCentralMeridian,
                      dfFalseEasting,
                      dfFalseNorthing : double
                      ) : TOGRErr; cdecl; external External_Lib name 'OSRSetGH';

  //** GEOS - Geostationary Satellite View */
  function   OSRSetGEOS(hSRS : TOGRSpatialReferenceH;
                        dfCentralMeridian, dfSatelliteHeight,
                        dfFalseEasting, dfFalseNorthing : double
                        ) : TOGRErr; cdecl; external External_Lib name 'OSRSetGEOS';

  //** Gauss Schreiber Transverse Mercator */
  function   OSRSetGaussSchreiberTMercator(hSRS :  TOGRSpatialReferenceH;
                                           dfCenterLat, dfCenterLong,
                                           dfScale,
                                           dfFalseEasting,
                                           dfFalseNorthing : double
                                           ) : TOGRErr; cdecl; external External_Lib name 'OSRSetGaussSchreiberTMercator';
  //** Gnomonic */
  function   OSRSetGnomonic(hSRS : TOGRSpatialReferenceH;
                            dfCenterLat, dfCenterLong,
                            dfFalseEasting, dfFalseNorthing : double
                            ) : TOGRErr; cdecl; external External_Lib name 'OSRSetGnomonic';
  //** Hotine Oblique Mercator using azimuth angle */
  function   OSRSetHOM(hSRS :  TOGRSpatialReferenceH;
                       dfCenterLat, dfCenterLong,
                       dfAzimuth, dfRectToSkew,
                       dfScale,
                       dfFalseEasting, dfFalseNorthing : double
                       ) : TOGRErr; cdecl; external External_Lib name 'OSRSetHOM';
  //** Hotine Oblique Mercator using two points on centerline */
  function   OSRSetHOM2PNO(hSRS :  TOGRSpatialReferenceH;
                           dfCenterLat,
                           dfLat1, dfLong1,
                           dfLat2, dfLong2,
                           dfScale,
                           dfFalseEasting, dfFalseNorthing : double
                           ) : TOGRErr; cdecl; external External_Lib name 'OSRSetHOM2PNO';
  //** International Map of the World Polyconic */
  function   OSRSetIWMPolyconic(hSRS :  TOGRSpatialReferenceH;
                                dfLat1, dfLat2,
                                dfCenterLong,
                                dfFalseEasting,
                                dfFalseNorthing : double
                                ) : TOGRErr; cdecl; external External_Lib name 'OSRSetIWMPolyconic';

  ///** Krovak Oblique Conic Conformal */
  function   OSRSetKrovak(hSRS :  TOGRSpatialReferenceH;
                          dfCenterLat, dfCenterLong,
                          dfAzimuth, dfPseudoStdParallelLat,
                          dfScale,
                          dfFalseEasting,
                          dfFalseNorthing : double
                          ) : TOGRErr; cdecl; external External_Lib name 'OSRSetKrovak';
  //** Lambert Azimuthal Equal-Area */
  function   OSRSetLAEA(hSRS :  TOGRSpatialReferenceH;
                        dfCenterLat, dfCenterLong,
                        dfFalseEasting, dfFalseNorthing : double
                        ) : TOGRErr; cdecl; external External_Lib name 'OSRSetLAEA';
  //** Lambert Conformal Conic */
  function   OSRSetLCC(hSRS :  TOGRSpatialReferenceH;
                       dfStdP1, dfStdP2,
                       dfCenterLat, dfCenterLong,
                       dfFalseEasting, dfFalseNorthing : double
                       ) : TOGRErr; cdecl; external External_Lib name 'OSRSetLCC';

  //** Lambert Conformal Conic 1SP */
  function   OSRSetLCC1SP(hSRS :  TOGRSpatialReferenceH;
                          dfCenterLat, dfCenterLong,
                          dfScale,
                          dfFalseEasting,
                          dfFalseNorthing : double
                          ) : TOGRErr; cdecl; external External_Lib name 'OSRSetLCC1SP';

  //** Lambert Conformal Conic (Belgium) */
  function   OSRSetLCCB(hSRS :  TOGRSpatialReferenceH;
                        dfStdP1, dfStdP2,
                        dfCenterLat, dfCenterLong,
                        dfFalseEasting, dfFalseNorthing : double
                        ) : TOGRErr; cdecl; external External_Lib name 'OSRSetLCCB';
  //** Miller Cylindrical */
  function   OSRSetMC(hSRS :  TOGRSpatialReferenceH;
                      dfCenterLat, dfCenterLong,
                      dfFalseEasting, dfFalseNorthing : double
                      ) : TOGRErr; cdecl; external External_Lib name 'OSRSetMC';

  //** Mercator */
  function   OSRSetMercator(hSRS :  TOGRSpatialReferenceH;
                            dfCenterLat, dfCenterLong,
                            dfScale,
                            dfFalseEasting, dfFalseNorthing : double
                            ) : TOGRErr; cdecl; external External_Lib name 'OSRSetMercator';

  //** Mollweide */
  function    OSRSetMollweide(hSRS :  TOGRSpatialReferenceH;
                              dfCentralMeridian,
                              dfFalseEasting,
                              dfFalseNorthing : double
                              ) : TOGRErr; cdecl; external External_Lib name 'OSRSetMollweide';

  //** New Zealand Map Grid */
  function   OSRSetNZMG(hSRS :  TOGRSpatialReferenceH;
                        dfCenterLat, dfCenterLong,
                        dfFalseEasting, dfFalseNorthing : double
                        ) : TOGRErr; cdecl; external External_Lib name 'OSRSetNZMG';

  //** Oblique Stereographic */
  function   OSRSetOS(hSRS :  TOGRSpatialReferenceH;
                      dfOriginLat, dfCMeridian,
                      dfScale,
                      dfFalseEasting, dfFalseNorthing : double
                      ) : TOGRErr; cdecl; external External_Lib name 'OSRSetOS';
  //** Orthographic */
  function   OSRSetOrthographic(hSRS :  TOGRSpatialReferenceH;
                                dfCenterLat, dfCenterLong,
                                dfFalseEasting,
                                dfFalseNorthing : double
                                ) : TOGRErr; cdecl; external External_Lib name 'OSRSetOrthographic';
  //** Polyconic */
  function   OSRSetPolyconic(hSRS :  TOGRSpatialReferenceH;
                             dfCenterLat, dfCenterLong,
                             dfFalseEasting, dfFalseNorthing : double
                             ) : TOGRErr; cdecl; external External_Lib name 'OSRSetPolyconic';
  //** Polar Stereographic */
  function   OSRSetPS(hSRS :  TOGRSpatialReferenceH;
                      dfCenterLat, dfCenterLong,
                      dfScale,
                      dfFalseEasting, dfFalseNorthing : double
                      ) : TOGRErr; cdecl; external External_Lib name 'OSRSetPS';
  //** Robinson */
  function   OSRSetRobinson(hSRS :  TOGRSpatialReferenceH;
                            dfCenterLong,
                            dfFalseEasting, dfFalseNorthing : double
                            ) : TOGRErr; cdecl; external External_Lib name 'OSRSetRobinson';
  //** Sinusoidal */
  function   OSRSetSinusoidal(hSRS :  TOGRSpatialReferenceH;
                              dfCenterLong,
                              dfFalseEasting,
                              dfFalseNorthing : double
                              ) : TOGRErr; cdecl; external External_Lib name 'OSRSetSinusoidal';

  //** Stereographic */
  function   OSRSetStereographic(hSRS :  TOGRSpatialReferenceH;
                                 dfCenterLat, dfCenterLong,
                                 dfScale,
                                 dfFalseEasting,
                                 dfFalseNorthing : double
                                 ) : TOGRErr; cdecl; external External_Lib name 'OSRSetStereographic';

  //** Swiss Oblique Cylindrical */
  function   OSRSetSOC(hSRS :  TOGRSpatialReferenceH;
                       dfLatitudeOfOrigin, dfCentralMeridian,
                       dfFalseEasting, dfFalseNorthing : double
                       ) : TOGRErr; cdecl; external External_Lib name 'OSRSetSOC';

  //** Transverse Mercator */
  function   OSRSetTM(hSRS :  TOGRSpatialReferenceH;
                      dfCenterLat, dfCenterLong,
                      dfScale,
                      dfFalseEasting, dfFalseNorthing : double
                      ) : TOGRErr; cdecl; external External_Lib name 'OSRSetTM';

  //** Transverse Mercator variant */
  function   OSRSetTMVariant(hSRS :  TOGRSpatialReferenceH;
                             pszVariantName : PCHAR;
                             dfCenterLat, dfCenterLong,
                             dfScale,
                             dfFalseEasting, dfFalseNorthing : double
                             ) : TOGRErr; cdecl; external External_Lib name 'OSRSetTMVariant';

  //** Tunesia Mining Grid  */
  function   OSRSetTMG(hSRS :  TOGRSpatialReferenceH;
                       dfCenterLat, dfCenterLong,
                       dfFalseEasting, dfFalseNorthing : double
                       ) : TOGRErr; cdecl; external External_Lib name 'OSRSetTMG';

  //** Transverse Mercator (South Oriented) */
  function   OSRSetTMSO(hSRS :  TOGRSpatialReferenceH;
                        dfCenterLat, dfCenterLong,
                        dfScale,
                        dfFalseEasting, dfFalseNorthing : double
                        ) : TOGRErr; cdecl; external External_Lib name 'OSRSetTMSO';

  //** VanDerGrinten */
  function   OSRSetVDG(hSRS :  TOGRSpatialReferenceH;
                       dfCenterLong,
                       dfFalseEasting, dfFalseNorthing : double
                       ) : TOGRErr; cdecl; external External_Lib name 'OSRSetVDG';

  //** Wagner I -- VII */
  function   OSRSetWagner(hSRS :  TOGRSpatialReferenceH; nVariation : longint;
                          dfFalseEasting,
                          dfFalseNorthing : double
                          ) : TOGRErr; cdecl; external External_Lib name 'OSRSetWagner';

procedure OSRCleanup; cdecl; external External_Lib name 'OSRCleanup';


//* -------------------------------------------------------------------- */
//*      Projection transform dictionary query.                          */
//* -------------------------------------------------------------------- */

function OPTGetProjectionMethods : PPCHAR; cdecl; external External_Lib name 'OPTGetProjectionMethods';
function OPTGetParameterList(pszProjectionMethod : PCHAR;
                             ppszUserName : PPCHAR
                             ) : PPCHAR; cdecl; external External_Lib name 'OPTGetParameterList';
function OPTGetParameterInfo(pszProjectionMethod : PCHAR;
                             pszParameterName : PCHAR;
                             ppszUserName : PPCHAR;
                             ppszType : PPCHAR;
                             pdfDefaultValue : PDOUBLE
                             ) : longint; cdecl; external External_Lib name 'OPTGetParameterInfo';


  function  OCTNewCoordinateTransformation (hSourceSRS : TOGRCoordinateTransformationH;
                                            hTargetSRS : TOGRCoordinateTransformationH
                                            ) : TOGRCoordinateTransformationH ;
                                            stdcall; external External_Lib name '_OCTNewCoordinateTransformation@8';
  procedure OCTDestroyCoordinateTransformation (const Handle : TOGRCoordinateTransformationH); stdcall; external External_Lib name '_OCTDestroyCoordinateTransformation@4';
  function  OCTTransformEx (const Handle : TOGRCoordinateTransformationH; const PointCount : longint;
                                 X, Y, Z : PDOUBLE;
                                 pSuccess : PINTEGER) : longint; stdcall; external External_Lib name '_OCTTransformEx@24';
  function  OCTTransform (const Handle : TOGRCoordinateTransformationH; const PointCount : longint;
                                 X, Y, Z : PDOUBLE
                                 ) : longint; stdcall; external External_Lib name '_OCTTransform@20';

implementation

end.

